@@ -51,5 +51,21 @@ def linechecker(FILENAME):
             print(bcolors.FAIL +  FILENAME + " has not been created or has %d lines" % num_lines + bcolors.ENDC)
     except FileNotFoundError:
         print(bcolors.FAIL +  FILENAME + " is not created"+ bcolors.ENDC)
+
+
+def linetotalchecker(FILENAME,TOTALNUMBER):
+    try:
+        with open(FILENAME) as file_content:
+            contents = file_content.read()
+            for x in contents.splitlines():
+                if TOTALNUMBER in x:
+                    print(bcolors.OKGREEN +"Counted line is correct" + bcolors.ENDC  )
+                else:
+                    print("Counted line might be incorrect")
+    except FileNotFoundError:
+        print(bcolors.FAIL +  FILENAME + " is not created"+ bcolors.ENDC)
+        sys.exit(1)
+    time.sleep(0.5)
+
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
 
